﻿using System;
using System.Windows;

namespace WpfGoogleMapClient
{
	/// <summary>
	/// MainWindow.xaml の相互作用ロジック
	/// </summary>
	public partial class MainWindow : Window
	{
		/// <summary>
		/// インスタンスを初期化します。
		/// </summary>
		public MainWindow()
		{
			string uri = String.Format( "file://{0}index.html", AppDomain.CurrentDomain.BaseDirectory );
			this.DataContext = new MainWindowViewModel( uri ) { Address = "東京" };

			this.InitializeComponent();
		}

		/// <summary>
		/// 移動ボタンが押された時に発生するイベントです。
		/// </summary>
		/// <param name="sender">イベント発生元。</param>
		/// <param name="e">イベント データ。</param>
		private void OnClickGoButton( object sender, RoutedEventArgs e )
		{
			var context = this.DataContext as MainWindowViewModel;
			if( context == null ) { return; }

			// JavaScript の関数を呼び出す。
			this._webBrowser.InvokeScript( "moveMap", context.Address );
		}
	}

	/// <summary>
	/// MainWindow の Model と View を仲介するクラスです。
	/// </summary>
	class MainWindowViewModel
	{
		/// <summary>
		/// インスタンスを初期化します。
		/// </summary>
		/// <param name="uri">ブラウザに表示するページの URI。</param>
		public MainWindowViewModel( string uri )
		{
			this.Uri = uri;
		}
		/// <summary>
		/// Google Map に指定する住所を取得または設定します。
		/// </summary>
		public string Address { get; set; }

		/// <summary>
		/// ブラウザに表示するページの URI を取得します。
		/// </summary>
		public string Uri { get; private set; }
	}
}
